@@ -1,8 +1,12 @@
 import subsurface.io
+import subsurface.interfaces
 from subsurface.structs import *
 from ._version import __version__
 
 try:
-    import subsurface.visualization
+    from subsurface import visualization
 except ImportError:
     pass
+
+if __name__ == '__main__':
+    pass
