@@ -5,10 +5,11 @@ from subsurface.structs.base_structures import UnstructuredData, StructuredData
 
 class Common(object):
     """A set of shared functionality for all spatially referenced data."""
-    data: Union[UnstructuredData, StructuredData]
+    mesh: Union[UnstructuredData, StructuredData]
 
     def validate(self):
         raise NotImplementedError()
 
     def to_pyvista(self):
         raise NotImplementedError()
+
